package com.ho.test.mail.ex1.server.testing;

import java.io.IOException;
import java.util.Calendar;

import javax.mail.internet.MimeMessage;

import junit.framework.TestCase;

import org.springframework.mail.javamail.JavaMailSenderImpl;
import org.springframework.mail.javamail.MimeMessageHelper;

import com.ho.test.mail.ex1.server.FakeSMTPServer;

/**
 * <p>Title: FakeSMTPServerTest</p>
 * 
 * <p>
 * Verify if the fake SMTP server works.
 * </p>
 * 
 */

public class FakeSMTPServerTest extends TestCase {

	// -------------------------------------------------------------- CONSTANTS
	// ----------------------------------------------------- PRIVATE ATTRIBUTES
	// ------------------------------------------------------------- EXCEPTIONS
	// ------------------------------------------------------- INTERNAL CLASSES
	// ----------------------------------------------------------- CONSTRUCTORS
	// --------------------------------------------------------- PUBLIC METHODS
	public void testFakeSMTPServer() {
		
		// Fake SMTP server port
		int smtpPort = 22501;
		
		// Build and start a Fake SMTP server
		FakeSMTPServer smtpServer = null;
		{
			try {
				smtpServer = new FakeSMTPServer(smtpPort);
			} catch (IOException e) {
				fail(e.getMessage());
			} // end-try
		} // end-block
		
		// Build a fake mail and send it to the mail server...
		String toAddress = "toAddress@junit.test";
		String htmlMsg = "<html><body>ceci est le corps du message...</body></html>";
		{
			JavaMailSenderImpl sender = new JavaMailSenderImpl();
			sender.setHost("localhost");
			sender.setPort(smtpPort);

			MimeMessage message = sender.createMimeMessage();
			MimeMessageHelper helper;
			try {
				helper = new MimeMessageHelper(message, true);
				helper.setTo(toAddress);
				helper.setText(htmlMsg,true);
				sender.send(message);
			} catch (javax.mail.MessagingException e) {
				fail(e.getMessage());
			} // end-try
		} // end-block
		
		pWait(1000);
		
		// Verify if the SMTP server received the mail.
		{
			assertTrue(smtpServer.isInLog(toAddress));
			assertTrue(smtpServer.isInLog(htmlMsg));
			assertTrue(smtpServer.isInLog("QUIT"));
		} // end-block
		
	}

	// -------------------------------------------------------- PRIVATE METHODS
    private void pWait(long time) {
        long begin = Calendar.getInstance().getTimeInMillis();
        while ( (Calendar.getInstance().getTimeInMillis() - begin) < time);
    }

	// ------------------------------------------------------ PROTECTED METHODS
	// --------------------------------------------- ADVANCED GETTERS & SETTERS
	// ------------------------------------------------------ GETTERS & SETTERS
}
